Datasets
========

This module contains dataset classes and utilities for loading and processing molecular data.

Core Dataset Classes
--------------------

.. automodule:: atomworks.ml.datasets.datasets
   :members:
   :undoc-members:
   :show-inheritance:

Parsers
-------

.. automodule:: atomworks.ml.datasets.parsers
   :members:
   :undoc-members:
   :show-inheritance: 